@@ -33,7 +33,7 @@ from nautobot_ssot_aristacv.diffsync import cvutils
 name = "SSoT - Arista CloudVision"  # pylint: disable=invalid-name
 
 
-class CloudVisionDataSource(DataSource, Job):
+class CloudVisionDataSource(DataSource, Job):  # pylint: disable=abstract-method
     """CloudVision SSoT Data Source."""
 
     debug = BooleanVar(description="Enable for more verbose debug logging")
@@ -41,7 +41,7 @@ class CloudVisionDataSource(DataSource, Job):
     class Meta:
         """Meta data for DataSource."""
 
-        name = "CloudVision -> Nautobot"
+        name = "CloudVision ⟹ Nautobot"
         data_source = "Cloudvision"
         data_source_icon = static("nautobot_ssot_aristacv/cvp_logo.png")
         description = "Sync system tag data from CloudVision to Nautobot"
@@ -155,7 +155,7 @@ class CloudVisionDataSource(DataSource, Job):
         return None
 
 
-class CloudVisionDataTarget(DataTarget, Job):
+class CloudVisionDataTarget(DataTarget, Job):  # pylint: disable=abstract-method
     """CloudVision SSoT Data Target."""
 
     debug = BooleanVar(description="Enable for more verbose debug logging")
@@ -163,7 +163,7 @@ class CloudVisionDataTarget(DataTarget, Job):
     class Meta:
         """Meta data for DataTarget."""
 
-        name = "Nautobot -> CloudVision"
+        name = "Nautobot ⟹ CloudVision"
         data_target = "CloudVision"
         data_target_icon = static("nautobot_ssot_aristacv/cvp_logo.png")
         description = "Sync tag data from Nautobot to CloudVision"
